summaryrefslogtreecommitdiff
path: root/cop.h
diff options
context:
space:
mode:
authorGurusamy Sarathy <gsar@cpan.org>1999-11-15 14:34:36 +0000
committerGurusamy Sarathy <gsar@cpan.org>1999-11-15 14:34:36 +0000
commitce2f7c3be671853dd8e435baa8ec8d4453b3bb86 (patch)
tree9869a562c62eedb4b463c1232a7b5c3da638159f /cop.h
parent62fde6427850206f9043b1f1a24485f145ebce72 (diff)
downloadperl-ce2f7c3be671853dd8e435baa8ec8d4453b3bb86.tar.gz
cloning the stack (part 1)
p4raw-id: //depot/perl@4588
Diffstat (limited to 'cop.h')
-rw-r--r--cop.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/cop.h b/cop.h
index af29ff6678..88627d684e 100644
--- a/cop.h
+++ b/cop.h
@@ -370,7 +370,7 @@ struct stackinfo {
I32 si_type; /* type of runlevel */
struct stackinfo * si_prev;
struct stackinfo * si_next;
- I32 * si_markbase; /* where markstack begins for us.
+ I32 si_markoff; /* offset where markstack begins for us.
* currently used only with DEBUGGING,
* but not #ifdef-ed for bincompat */
};
@@ -382,9 +382,10 @@ typedef struct stackinfo PERL_SI;
#define cxstack_max (PL_curstackinfo->si_cxmax)
#ifdef DEBUGGING
-# define SET_MARKBASE PL_curstackinfo->si_markbase = PL_markstack_ptr
+# define SET_MARK_OFFSET \
+ PL_curstackinfo->si_markoff = PL_markstack_ptr - PL_markstack
#else
-# define SET_MARKBASE NOOP
+# define SET_MARK_OFFSET NOOP
#endif
#define PUSHSTACKi(type) \
@@ -400,7 +401,7 @@ typedef struct stackinfo PERL_SI;
AvFILLp(next->si_stack) = 0; \
SWITCHSTACK(PL_curstack,next->si_stack); \
PL_curstackinfo = next; \
- SET_MARKBASE; \
+ SET_MARK_OFFSET; \
} STMT_END
#define PUSHSTACK PUSHSTACKi(PERLSI_UNKNOWN)